@@ -12,6 +12,20 @@ gets a better compression ratio than xz, and is much faster.  See
 [ARCHIVE](https://github.com/asayers/sqlite2parquet/blob/master/ARCHIVE.md)
 for a comparison.
 
+## The easy way
+
+If you just want to dump the whole table as-is into a parquet file, you can
+use the handy [`infer_schema()`].  It tries to guess the best encoding based
+on the sqlite schema.
+
+```rust
+# let conn = rusqlite::Connection::open_in_memory().unwrap();
+# conn.execute("CREATE TABLE my_table (category TEXT, timestamp DATETIME)", []);
+let cols = sqlite2parquet::infer_schema(&conn, "my_table").unwrap();
+let out_path = std::path::PathBuf::from("my_table.parquet");
+sqlite2parquet::write_table(&conn, "my_table", &cols, &out_path, 1_000_000).unwrap();
+```
+
 ## The flexible way
 
 Explicitly define the columns that will go in the parquet file.  One thing
@@ -19,9 +33,8 @@ to be careful about: the `SELECT` queries must all return the same number
 of rows.  If not, you'll get a runtime error.
 
 ```rust
-let conn = rusqlite::Connection::open_in_memory().unwrap();
-conn.execute("CREATE TABLE my_table (category TEXT, timestamp DATETIME)", []);
-
+# let conn = rusqlite::Connection::open_in_memory().unwrap();
+# conn.execute("CREATE TABLE my_table (category TEXT, timestamp DATETIME)", []);
 use parquet::basic::*;
 use parquet_format::NanoSeconds;
 let cols = vec![
@@ -47,21 +60,6 @@ let cols = vec![
 
 let out_path = std::path::PathBuf::from("category_start_times.parquet");
 sqlite2parquet::write_table(&conn, "category_start_times", &cols, &out_path, 1_000_000).unwrap();
-```
-
-## The easy way
-
-If you just want to dump the whole table as-is into a parquet file, you can
-use the handy [`infer_schema()`].  It tries to guess the best encoding based
-on the sqlite schema.
-
-```rust
-let conn = rusqlite::Connection::open_in_memory().unwrap();
-conn.execute("CREATE TABLE my_table (category TEXT, timestamp DATETIME)", []);
-
-let cols = sqlite2parquet::infer_schema(&conn, "my_table").unwrap();
-let out_path = std::path::PathBuf::from("my_table.parquet");
-sqlite2parquet::write_table(&conn, "my_table", &cols, &out_path, 1_000_000).unwrap();
 ```
 
  */
@@ -85,7 +83,7 @@ fn mk_writer(
 ) -> Result<impl parquet::file::writer::FileWriter> {
     let mut fields = cols
         .iter()
-        .map(|col| Arc::new(col.clone().as_parquet().unwrap()))
+        .map(|col| Arc::new(col.as_parquet().unwrap()))
         .collect::<Vec<_>>();
     let schema = parquet::schema::types::Type::group_type_builder(table_name)
         .with_fields(&mut fields)
@@ -121,7 +119,7 @@ fn mk_writer(
 /// wants to read the final row in a group, it has to start at the beginning
 /// of the group and decompress to the end.  I would suggest 100k to 1M is
 /// a sensible default.
-pub fn write_table<'a>(
+pub fn write_table(
     conn: &Connection,
     table_name: &str,
     cols: &[Column],
@@ -142,7 +140,7 @@ pub fn write_table<'a>(
 /// * Number of row groups fully written
 ///
 /// For more information, see the docs for [`write_table()`].
-pub fn write_table_with_progress<'a>(
+pub fn write_table_with_progress(
     conn: &Connection,
     table_name: &str,
     cols: &[Column],
@@ -150,7 +148,7 @@ pub fn write_table_with_progress<'a>(
     group_size: usize,
     mut progress_cb: impl FnMut(u64, u64, u64) -> Result<()>,
 ) -> Result<parquet_format::FileMetaData> {
-    let mut wtr = mk_writer(table_name, &cols, out)?;
+    let mut wtr = mk_writer(table_name, cols, out)?;
 
     let mut stmnts = cols
         .iter()
@@ -178,7 +176,7 @@ pub fn write_table_with_progress<'a>(
     Ok(metadata)
 }
 
-fn write_group<'a>(
+fn write_group(
     wtr: &mut impl parquet::file::writer::FileWriter,
     selects: &mut [rusqlite::Rows],
     group_size: usize,
@@ -212,7 +210,7 @@ fn write_group<'a>(
     Ok(())
 }
 
-fn write_col<'a, T>(
+fn write_col<T>(
     iter: &mut rusqlite::Rows,
     group_size: usize,
     wtr: &mut parquet::column::writer::ColumnWriterImpl<T>,
